pub struct SteepestDescent<L> { /* private fields */ }Expand description
Steepest descent
Iteratively takes steps in the direction of the strongest negative gradient. In each iteration, a line search is used to obtain an appropriate step length.
Requirements on the optimization problem
The optimization problem is required to implement CostFunction and Gradient.
Reference
Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization. Springer. ISBN 0-387-30303-0.
Implementations
Sourceimpl<L> SteepestDescent<L>
impl<L> SteepestDescent<L>
Sourcepub fn new(linesearch: L) -> Self
pub fn new(linesearch: L) -> Self
Construct a new instance of SteepestDescent
Requires a line search.
Example
let sd = SteepestDescent::new(linesearch);Trait Implementations
Sourceimpl<L: Clone> Clone for SteepestDescent<L>
impl<L: Clone> Clone for SteepestDescent<L>
Sourcefn clone(&self) -> SteepestDescent<L>
fn clone(&self) -> SteepestDescent<L>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de, L> Deserialize<'de> for SteepestDescent<L>where
L: Deserialize<'de>,
impl<'de, L> Deserialize<'de> for SteepestDescent<L>where
L: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<L> Serialize for SteepestDescent<L>where
L: Serialize,
impl<L> Serialize for SteepestDescent<L>where
L: Serialize,
Sourceimpl<O, L, P, G, F> Solver<O, IterState<P, G, (), (), (), F>> for SteepestDescent<L>where
O: CostFunction<Param = P, Output = F> + Gradient<Param = P, Gradient = G>,
P: Clone,
G: Clone + ArgminMul<F, G>,
L: Clone + LineSearch<G, F> + Solver<O, IterState<P, G, (), (), (), F>>,
F: ArgminFloat,
impl<O, L, P, G, F> Solver<O, IterState<P, G, (), (), (), F>> for SteepestDescent<L>where
O: CostFunction<Param = P, Output = F> + Gradient<Param = P, Gradient = G>,
P: Clone,
G: Clone + ArgminMul<F, G>,
L: Clone + LineSearch<G, F> + Solver<O, IterState<P, G, (), (), (), F>>,
F: ArgminFloat,
Sourcefn next_iter(
&mut self,
problem: &mut Problem<O>,
state: IterState<P, G, (), (), (), F>,
) -> Result<(IterState<P, G, (), (), (), F>, Option<KV>), Error>
fn next_iter( &mut self, problem: &mut Problem<O>, state: IterState<P, G, (), (), (), F>, ) -> Result<(IterState<P, G, (), (), (), F>, Option<KV>), Error>
Computes a single iteration of the algorithm and has access to the optimization problem
definition and the internal state of the solver.
Returns an updated
state and optionally a KV which holds key-value pairs used in
Observers.Sourcefn init(
&mut self,
_problem: &mut Problem<O>,
state: I,
) -> Result<(I, Option<KV>), Error>
fn init( &mut self, _problem: &mut Problem<O>, state: I, ) -> Result<(I, Option<KV>), Error>
Initializes the algorithm. Read more
Sourcefn terminate_internal(&mut self, state: &I) -> TerminationStatus
fn terminate_internal(&mut self, state: &I) -> TerminationStatus
Checks whether basic termination reasons apply. Read more
Sourcefn terminate(&mut self, _state: &I) -> TerminationStatus
fn terminate(&mut self, _state: &I) -> TerminationStatus
Used to implement stopping criteria, in particular criteria which are not covered by
(
terminate_internal. Read moreAuto Trait Implementations
impl<L> Freeze for SteepestDescent<L>where
L: Freeze,
impl<L> RefUnwindSafe for SteepestDescent<L>where
L: RefUnwindSafe,
impl<L> Send for SteepestDescent<L>where
L: Send,
impl<L> Sync for SteepestDescent<L>where
L: Sync,
impl<L> Unpin for SteepestDescent<L>where
L: Unpin,
impl<L> UnwindSafe for SteepestDescent<L>where
L: UnwindSafe,